@@ -30,6 +30,11 @@
 #endif
 #define LRU11_DO_NOT_DEFINE_OUT_OF_CLASS_METHODS
 
+#if defined(HAVE_LIBDL) && !defined(_GNU_SOURCE)
+// Required for dladdr() on Cygwin
+#define _GNU_SOURCE
+#endif
+
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
@@ -1419,6 +1424,22 @@ static void *pj_open_lib_internal(
         if (out_full_filename != nullptr && out_full_filename_size > 0)
             out_full_filename[0] = '\0';
 
+        auto open_lib_from_paths = [&ctx, open_file, &name, &fname, &sysname,
+                                    &mode](const std::string &projLibPaths) {
+            void *lib_fid = nullptr;
+            auto paths = NS_PROJ::internal::split(projLibPaths, dirSeparator);
+            for (const auto &path : paths) {
+                fname = NS_PROJ::internal::stripQuotes(path);
+                fname += DIR_CHAR;
+                fname += name;
+                sysname = fname.c_str();
+                lib_fid = open_file(ctx, sysname, mode);
+                if (lib_fid)
+                    break;
+            }
+            return lib_fid;
+        };
+
         /* check if ~/name */
         if (is_tilde_slash(name))
             if ((sysname = getenv("HOME")) != nullptr) {
@@ -1486,16 +1507,7 @@ static void *pj_open_lib_internal(
         else if (!gbPROJ_LIB_ENV_VAR_TRIED_LAST &&
                  !(projLib = NS_PROJ::FileManager::getProjLibEnvVar(ctx))
                       .empty()) {
-            auto paths = NS_PROJ::internal::split(projLib, dirSeparator);
-            for (const auto &path : paths) {
-                fname = path;
-                fname += DIR_CHAR;
-                fname += name;
-                sysname = fname.c_str();
-                fid = open_file(ctx, sysname, mode);
-                if (fid)
-                    break;
-            }
+            fid = open_lib_from_paths(projLib);
         }
 
         else if ((sysname = get_path_from_relative_share_proj(
@@ -1518,16 +1530,7 @@ static void *pj_open_lib_internal(
         else if (gbPROJ_LIB_ENV_VAR_TRIED_LAST &&
                  !(projLib = NS_PROJ::FileManager::getProjLibEnvVar(ctx))
                       .empty()) {
-            auto paths = NS_PROJ::internal::split(projLib, dirSeparator);
-            for (const auto &path : paths) {
-                fname = path;
-                fname += DIR_CHAR;
-                fname += name;
-                sysname = fname.c_str();
-                fid = open_file(ctx, sysname, mode);
-                if (fid)
-                    break;
-            }
+            fid = open_lib_from_paths(projLib);
         }
 
         else {
@@ -1790,11 +1793,37 @@ void pj_load_ini(PJ_CONTEXT *ctx) {
     if (ctx->iniFileLoaded)
         return;
 
+    // Start reading environment variables that have priority over the
+    // .ini file
+    const char *proj_network = getenv("PROJ_NETWORK");
+    if (proj_network && proj_network[0] != '\0') {
+        ctx->networking.enabled = ci_equal(proj_network, "ON") ||
+                                  ci_equal(proj_network, "YES") ||
+                                  ci_equal(proj_network, "TRUE");
+    } else {
+        proj_network = nullptr;
+    }
+
     const char *endpoint_from_env = getenv("PROJ_NETWORK_ENDPOINT");
     if (endpoint_from_env && endpoint_from_env[0] != '\0') {
         ctx->endpoint = endpoint_from_env;
     }
 
+    // Custom path to SSL certificates.
+    const char *ca_bundle_path = getenv("PROJ_CURL_CA_BUNDLE");
+    if (ca_bundle_path == nullptr) {
+        // Name of environment variable used by the curl binary
+        ca_bundle_path = getenv("CURL_CA_BUNDLE");
+    }
+    if (ca_bundle_path == nullptr) {
+        // Name of environment variable used by the curl binary (tested
+        // after CURL_CA_BUNDLE
+        ca_bundle_path = getenv("SSL_CERT_FILE");
+    }
+    if (ca_bundle_path != nullptr) {
+        ctx->ca_bundle_path = ca_bundle_path;
+    }
+
     ctx->iniFileLoaded = true;
     auto file = std::unique_ptr<NS_PROJ::File>(
         reinterpret_cast<NS_PROJ::File *>(pj_open_lib_internal(
@@ -1826,13 +1855,10 @@ void pj_load_ini(PJ_CONTEXT *ctx) {
                 trim(content.substr(equal + 1, eol - (equal + 1)));
             if (ctx->endpoint.empty() && key == "cdn_endpoint") {
                 ctx->endpoint = value;
-            } else if (key == "network") {
-                const char *enabled = getenv("PROJ_NETWORK");
-                if (enabled == nullptr || enabled[0] == '\0') {
-                    ctx->networking.enabled = ci_equal(value, "ON") ||
-                                              ci_equal(value, "YES") ||
-                                              ci_equal(value, "TRUE");
-                }
+            } else if (proj_network == nullptr && key == "network") {
+                ctx->networking.enabled = ci_equal(value, "ON") ||
+                                          ci_equal(value, "YES") ||
+                                          ci_equal(value, "TRUE");
             } else if (key == "cache_enabled") {
                 ctx->gridChunkCache.enabled = ci_equal(value, "ON") ||
                                               ci_equal(value, "YES") ||
@@ -1855,6 +1881,8 @@ void pj_load_ini(PJ_CONTEXT *ctx) {
                         ctx, PJ_LOG_ERROR,
                         "pj_load_ini(): Invalid value for tmerc_default_algo");
                 }
+            } else if (ca_bundle_path == nullptr && key == "ca_bundle_path") {
+                ctx->ca_bundle_path = value;
             }
         }
 
@@ -1958,6 +1986,7 @@ void proj_context_set_ca_bundle_path(PJ_CONTEXT *ctx, const char *path) {
         ctx = pj_get_default_ctx();
     if (!ctx)
         return;
+    pj_load_ini(ctx);
     try {
         ctx->set_ca_bundle_path(path != nullptr ? path : "");
     } catch (const std::exception &) {
